<template>
  <el-dialog
    v-diadrag
    title="库位"
    top="1vh"
    :visible.sync="innerVisible"
    append-to-body
    @close="$emit('update:currshowlist', false)"
    :show="currshowlist"
    width="50%"
  >
    <ttable
      :table="table"
      @current-change="handleCurrentChange"
      :uploadInfo="uploadInfo"
      max-height="600px"
      :isShowHide="true"
      :prelang="prelang"
      :options="options"
      :ajaxFun="ajaxFun"
      ref="locationTable"
    >
      <template #toolbar></template>
    </ttable>
    <span slot="footer" class="dialog-footer">
      <el-button @click="innerVisible = false">取消</el-button>
      <el-button type="primary" v-thinclick="`dataFormSubmit`">确定</el-button>
    </span>
  </el-dialog>
</template>
<script>
import { fetchList } from '@/api/warehouse/location'
import { mapGetters } from 'vuex'
import { remote } from '../../../api/admin/dict'
import ttable from '@/views/common/ztt-table.vue'
import { loadWarehouse, getIfsLocation } from '../../../api/warehouse/location'
export default {
  props: {
    currshowlist: {
      type: Boolean,
      default: false
    }
  },
  data() {
    return {
      innerVisible: false,
      isSubmit: false,
      processModeval: null,
      ajaxFun: fetchList,
      warehouseOptions: [],
      locTypeOptions: [],
      dataForm: {},
      ifsLocationOptions: [],
      mulLocation: [],
      uploadInfo: {
        // 是否展示上传EXCEL以及对应的url
        isShow: true,
        url: '/mes/location/upload'
      },
      prelang: 'operation',
      options: {
        height: 300, // 默认高度-为了表头固定
        stripe: true, // 是否为斑马纹 table
        highlightCurrentRow: false, // 是否要高亮当前行
        border: true, // 是否有纵向边框
        lazy: false, // 是否需要懒加载
        fit: true, // 列的宽度是否自撑开
        multiSelect: false, //
        seqNo: true,
        isShowHide: true, // 是否显示显影按钮
        isSearch: true, // 高级查询按钮
        defaultOrderBy: { column: 'createTime', direction: 'desc' }
      },
      table: {
        total: 0,
        currentPage: 1,
        pageSize: 20,
        data: [],
        // 标题
        column: [
          // 工厂
          {
            minWidth: '140',
            prop: 'factoryName',
            label: '工厂',
            sort: true,
            isTrue: true,
            isSearch: true,
            searchInfoType: 'text'
          },
          // 库位编号
          {
            minWidth: '120',
            prop: 'locNo',
            label: '库位编号',
            sort: true,
            isTrue: true,
            isSearch: true,
            searchInfoType: 'text'
          },
          // 库位名称
          {
            minWidth: '200',
            prop: 'locName',
            label: '库位名称',
            sort: true,
            isTrue: true,
            isSearch: true,
            searchInfoType: 'text'
          },
          // 库位描述
          {
            minWidth: '140',
            prop: 'locDesc',
            label: '库位描述',
            sort: true,
            isTrue: true,
            isSearch: false,
            searchInfoType: 'text'
          },
          // 库位类型
          {
            minWidth: '120',
            prop: 'locType',
            label: '库位类型',
            sort: true,
            isTrue: true,
            formatter: this.locationType,
            isSearch: true,
            searchInfoType: 'select',
            optList: () => {
              return this.locTypeOptions
            }
          },
          // 库位地址
          {
            minWidth: '200',
            prop: 'locAddr',
            label: '库位地址',
            sort: true,
            isTrue: true,
            isSearch: false,
            searchInfoType: 'text'
          },
          // 库位地图
          {
            minWidth: '140',
            prop: 'locMap',
            label: '库位地图',
            sort: true,
            isTrue: true,
            isSearch: false,
            searchInfoType: 'text'
          },
          // 库位状态
          {
            minWidth: '120',
            prop: 'locStatus',
            label: '库位状态',
            sort: true,
            isTrue: true,
            isSearch: true,
            searchInfoType: 'select',
            optList: () => {
              return this.getLocationStatusOptionList()
            },
            formatter: (row, column, cellValue) => {
              return cellValue == 1 ? '使用' : '停产'
            }
          },
          // 备注
          {
            minWidth: '200',
            prop: 'locRemark',
            label: '备注',
            sort: true,
            isTrue: true,
            isSearch: false,
            searchInfoType: 'text'
          },
          // 创建时间
          {
            minWidth: '200',
            width: '300',
            prop: 'createTime',
            label: '创建时间',
            sort: true,
            isTrue: true,
            isSearch: true,
            searchInfoType: 'datetimerange'
          },
          // 所属仓库分组
          {
            minWidth: '200',
            prop: 'locGroup',
            label: '所属仓库分组',
            sort: true,
            isTrue: true,
            isSearch: true,
            searchInfoType: 'select',
            formatter: this.warehouseLocGroup,
            optList: () => {
              return this.getWarehouseLocGroupList()
            }
          },
          // IFS库位
          {
            minWidth: '200',
            prop: 'ifsLocation',
            label: 'IFS库位',
            sort: true,
            isTrue: true,
            isSearch: true,
            searchInfoType: 'text'
          }
        ],
        toolbar: [],
        operator: [],
        operatorConfig: {}
      },
      locationOptionList: [
        {
          value: 1,
          label: '使用'
        },
        {
          value: 0,
          label: '停产'
        }
      ]
    }
  },
  components: {
    ttable
  },
  watch: {
    currshowlist() {
      this.innerVisible = this.currshowlist
      if (this.currshowlist) {
        this.$nextTick(() => {
          this.getData()
        })
      }
    }
  },

  created() {
    this.getLocTypeCache('warehouse_type') // 获取定时任务运行时状态
    this.initWarehouseSelect()
    // this.getIFSLocationCache()
  },
  computed: {
    ...mapGetters(['permissions'])
  },

  methods: {
    init() {
      this.innerVisible = true
    },
    dataFormSubmit() {
      console.log(this.mulLocation)
      if (this.mulLocation) {
        this.$emit('refreshDataList', this.mulLocation)
        this.innerVisible = false
      } else {
        this.$message.error('请选择数据！')
      }
    },
    // 选中库位行
    handleCurrentChange(val) {
      this.mulLocation = val
      console.log(val)
    },
    getWarehouseLocGroupList() {
      const warehouseList = []
      let warehouse
      this.warehouseOptions.forEach((item) => {
        warehouse = {
          value: item.id,
          label: item.warehouseName
        }
        warehouseList.push(warehouse)
      })
      return warehouseList
    },
    getIFSLocationList() {
      return this.ifsLocationOptions
    },
    // 将id进行匹配显示为对应的仓库分组
    warehouseLocGroup(row, column, cellValue) {
      this.warehouseOptions.forEach((obj) => {
        if (obj.id == cellValue) {
          cellValue = obj.warehouseName
        }
      })
      return cellValue
    },
    // 格式化IFS库位
    formatIFSLocation(row, column, cellValue) {
      this.ifsLocationOptions.forEach((obj) => {
        if (obj.value == cellValue) {
          cellValue = obj.label
        }
      })
      return cellValue
    },
    /**
     * 获取字典显示名称并缓存
     */
    getLocTypeCache(type) {
      remote(type).then((response) => {
        const code = response.data.code
        if (code === 0) {
          const _data = response.data.data
          this.locTypeOptions = _data
        }
      })
    },
    /**
     * 获取IFS库位字典并缓存
     */
    getIFSLocationCache() {
      getIfsLocation().then((response) => {
        const code = response.data.code
        if (code === 0) {
          const _data = response.data.data
          this.ifsLocationOptions = []
          if (_data.length > 0) {
            _data.forEach((item) => {
              const ifsLocationOption = {
                value: item.LOCATION_NO,
                label: item.LOCATION_NO
              }
              this.ifsLocationOptions.push(ifsLocationOption)
            })
          }
        }
      })
    },
    /**
     * 获取字典定时任务执行状态字典值显示名称
     */
    locationType(row, column, cellValue) {
      this.locTypeOptions.forEach((obj) => {
        if (obj.value == cellValue) {
          cellValue = obj.label
        }
      })
      return cellValue
    },
    // 获取仓库的数据
    initWarehouseSelect() {
      loadWarehouse().then((res) => {
        this.warehouseOptions = res.data
      })
    },
    // 获取数据列表
    getData() {
      this.$refs.locationTable.getDataList()
    },

    getLocationStatusOptionList() {
      return this.locationOptionList
    }
  }
}
</script>
